==> janus_client-2.2.1.tar.gz: README.md <==
[![ko-fi](https://www.ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/U7U11OZL8)
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-6-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

<a href="https://www.buymeacoffee.com/gr20hjk" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" style="height: 51px !important;width: 217px !important;" ></a>
# janus_client

It is a feature rich flutter package, which offers all webrtc operations supported by [Janus: the general purpose WebRTC server](https://janus.conf.meetecho.com/),
it easily integrates into your flutter application and allows you to build webrtc features and functionality with clean and maintainable code.

## [Demo of JanusClient](https://flutterjanus.github.io/flutter_janus_client/example/build/web/#/)


## News & Updates
- Just like new flutter version comes With desktop support out of the box
- All major plugins fully support unified plan
- Typed examples updated with null safety and latest dart constraints
- Introduced plugin specific wrapper classes with respective operation methods for rich development experience
- Introduced typed events (Class Based Events) for brilliant auto completion support for IDE
- Supports null-safety

## Feature Status
| Feature           | Support | Well Tested | Unified Plan | Example |
|-------------------|---------|-------------|--------------|---------|
| WebSocket         | Yes     | Yes         | -            | Yes     |
| Rest/Http API     | Yes     | Yes         | -            | Yes     |
| Video Room Plugin | Yes     | No         | Yes          | Yes     |
| Video Call Plugin | Yes     | No          | Yes          | Yes     |
| Streaming Plugin  | Yes     | No          | Yes          | Yes     |
| Audio Room Plugin | Yes     | No          | Yes          | Yes     |
| Sip Plugin        | Yes     | No          | -           | No      |
| Text Room Plugin  | Yes     | No          | -          | Yes     |
| ScreenSharing using VideoRoom plugin  | Yes     | No          | Yes          | Yes     |

## Platform Support Table
| Platform           | Support | Well Tested|
|-------------------|---------|-------------|
| Browser(Web)      | Yes     | Yes         |
| MacOs             | Yes     | No          |
| Android           | Yes     | Yes         | 
| Ios               | Yes     | No          | 
| Linux             | Yes     | No          | 
| Windows           | Yes     | No          | 


## Todo
- Documentation of some remaining plugins
- Polishing of examples
- Unit Test cases for all plugins

## Deprecated Api v1(0.0.x)
If by any chance you are looking for (although you shouldn't) old api then you can switch to v1 branch,
as it is very unstable and hard to maintain it was deprecated and will not recieve any fixes or feature updates.
It is highly recommended you migrate your code to latest version that is 2.X.X (stable)

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/shivanshtalwar0"><img src="https://avatars.githubusercontent.com/u/26632663?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Shivansh Talwar</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=shivanshtalwar0" title="Code">💻</a> <a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=shivanshtalwar0" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/kzawadi"><img src="https://avatars.githubusercontent.com/u/12481289?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kelvin Zawadi</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=kzawadi" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/LifeNow"><img src="https://avatars.githubusercontent.com/u/18676202?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eugene</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=LifeNow" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/igala"><img src="https://avatars.githubusercontent.com/u/454390?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Igal Avraham</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=igala" title="Code">💻</a></td>
    <td align="center"><a href="https://vigikaran.me/"><img src="https://avatars.githubusercontent.com/u/9039584?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Vigikaran</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=vigikaran" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/UserSense"><img src="https://avatars.githubusercontent.com/u/65860664?v=4?s=100" width="100px;" alt=""/><br /><sub><b>UserSense</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=UserSense" title="Code">💻</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

==> janus_client-2.2.2.tar.gz: README.md <==
[![ko-fi](https://www.ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/U7U11OZL8)
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-7-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

<a href="https://www.buymeacoffee.com/gr20hjk" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" style="height: 51px !important;width: 217px !important;" ></a>
# janus_client

It is a feature rich flutter package, which offers all webrtc operations supported by [Janus: the general purpose WebRTC server](https://janus.conf.meetecho.com/),
it easily integrates into your flutter application and allows you to build webrtc features and functionality with clean and maintainable code.

## [Demo of JanusClient](https://flutterjanus.github.io/flutter_janus_client/example/build/web/#/)


## News & Updates
- Added errorHandler for typedMessage Stream for better development flow
- Just like new flutter version comes With desktop support out of the box
- All major plugins fully support unified plan
- Typed examples updated with null safety and latest dart constraints
- Introduced plugin specific wrapper classes with respective operation methods for rich development experience
- Introduced typed events (Class Based Events) for brilliant auto completion support for IDE
- Supports null-safety

## Feature Status
| Feature           | Support | Well Tested | Unified Plan | Example |
|-------------------|---------|-------------|--------------|---------|
| WebSocket         | Yes     | Yes         | -            | Yes     |
| Rest/Http API     | Yes     | Yes         | -            | Yes     |
| Video Room Plugin | Yes     | No         | Yes          | Yes     |
| Video Call Plugin | Yes     | No          | Yes          | Yes     |
| Streaming Plugin  | Yes     | No          | Yes          | Yes     |
| Audio Room Plugin | Yes     | No          | Yes          | Yes     |
| Sip Plugin        | Yes     | No          | -           | No      |
| Text Room Plugin  | Yes     | No          | -          | Yes     |
| ScreenSharing using VideoRoom plugin  | Yes     | No          | Yes          | Yes     |

## Platform Support Table
| Platform           | Support | Well Tested|
|-------------------|---------|-------------|
| Browser(Web)      | Yes     | Yes         |
| MacOs             | Yes     | No          |
| Android           | Yes     | Yes         | 
| Ios               | Yes     | No          | 
| Linux             | Yes     | No          | 
| Windows           | Yes     | No          | 


## Todo
- Documentation of some remaining plugins
- Polishing of examples
- Unit Test cases for all plugins

## Deprecated Api v1(0.0.x)
If by any chance you are looking for (although you shouldn't) old api then you can switch to v1 branch,
as it is very unstable and hard to maintain it was deprecated and will not recieve any fixes or feature updates.
It is highly recommended you migrate your code to latest version that is 2.X.X (stable)

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/shivanshtalwar0"><img src="https://avatars.githubusercontent.com/u/26632663?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Shivansh Talwar</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=shivanshtalwar0" title="Code">💻</a> <a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=shivanshtalwar0" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/kzawadi"><img src="https://avatars.githubusercontent.com/u/12481289?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kelvin Zawadi</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=kzawadi" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/LifeNow"><img src="https://avatars.githubusercontent.com/u/18676202?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eugene</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=LifeNow" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/igala"><img src="https://avatars.githubusercontent.com/u/454390?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Igal Avraham</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=igala" title="Code">💻</a></td>
    <td align="center"><a href="http://vigikaran.me/"><img src="https://avatars.githubusercontent.com/u/9039584?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Vigikaran</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=vigikaran" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/UserSense"><img src="https://avatars.githubusercontent.com/u/65860664?v=4?s=100" width="100px;" alt=""/><br /><sub><b>UserSense</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/commits?author=UserSense" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/baihua666"><img src="https://avatars.githubusercontent.com/u/5125983?v=4?s=100" width="100px;" alt=""/><br /><sub><b>baihua666</b></sub></a><br /><a href="https://github.com/flutterjanus/flutter_janus_client/issues?q=author%3Abaihua666" title="Bug reports">🐛</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
